.. Automatically generated by nengo-bones, do not edit this file directly

*********************
Contributing to Nengo
*********************

Issues and pull requests are always welcome!
We appreciate help from the community to make Nengo better.

Filing issues
=============

If you find a bug in Nengo,
or think that a certain feature is missing,
please consider
`filing an issue <https://github.com/nengo/nengo/issues>`_!
Please search the currently open issues first
to see if your bug or feature request already exists.
If so, feel free to add a comment to the issue
so that we know that multiple people are affected.

Making pull requests
====================

If you want to fix a bug or add a feature to Nengo,
we welcome pull requests.
Ensure that you fill out all sections of the pull request template,
deleting the comments as you go.

Contributor agreement
=====================

We require that all contributions be covered under
our contributor assignment agreement. Please see
`the agreement <https://www.nengo.ai/caa/>`_
for instructions on how to sign.

More details
============

For more details on how to contribute to Nengo,
please see the `developer guide <https://www.nengo.ai/contributing/>`_.
